@@ -5,7 +5,7 @@ use warnings;
 package Benchmark::Featureset::ParamCheck::Base::MXPV;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.001';
+our $VERSION   = '0.002';
 
 use parent qw(Benchmark::Featureset::ParamCheck::Base);
 use MooseX::Params::Validate 0.21;
@@ -18,4 +18,11 @@ sub run_named_check {
 	return;
 }
 
+sub run_positional_check {
+	my ($class, $times, @args) = @_;
+	my $check = $class->get_positional_check;
+	pos_validated_list(\@args, @$check) for 1 .. $times;
+	return;
+}
+
 1;
\ No newline at end of file
