@@ -5,7 +5,7 @@ use warnings;
 package Benchmark::Featureset::ParamCheck::Base::ParamsCheck;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.001';
+our $VERSION   = '0.002';
 
 use parent qw(Benchmark::Featureset::ParamCheck::Base);
 use Params::Check 0.38 qw(check);
@@ -13,6 +13,7 @@ use namespace::autoclean;
 
 use constant allow_extra_key => !!1;
 use constant accept_hash     => !!0;
+use constant accept_array    => !!0;
 
 sub run_named_check {
 	my ($class, $times, @args) = @_;
@@ -21,4 +22,8 @@ sub run_named_check {
 	return;
 }
 
+sub run_positional_check {
+	...;
+}
+
 1;
\ No newline at end of file
