@@ -5,7 +5,7 @@ use warnings;
 package Benchmark::Featureset::ParamCheck::Implementation::MXPV::Moose;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.001';
+our $VERSION   = '0.002';
 
 use parent qw(Benchmark::Featureset::ParamCheck::Base::MXPV);
 use Moose 2.2002 ();
@@ -25,4 +25,12 @@ sub get_named_check {
 	};
 }
 
+sub get_positional_check {
+	state $check = [
+		{ isa => $t->('Int') },
+		{ isa => $t->('ArrayRef[HashRef]') },
+		{ isa => duck_type(Printable => [qw/ print close /]) },
+	];
+}
+
 1;
