@@ -5,7 +5,7 @@ use warnings;
 package Benchmark::Featureset::ParamCheck::Implementation::MXPV::TypeTiny;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.001';
+our $VERSION   = '0.002';
 
 use parent qw(Benchmark::Featureset::ParamCheck::Base::MXPV);
 use Ref::Util 0.203 ();
@@ -25,4 +25,12 @@ sub get_named_check {
 	};
 }
 
+sub get_positional_check {
+	state $check = [
+		{ isa => Int },
+		{ isa => ArrayRef[HashRef] },
+		{ isa => HasMethods[qw/ print close /] },
+	];
+}
+
 1;
