@@ -5,7 +5,7 @@ use warnings;
 package Benchmark::Featureset::ParamCheck::Implementation::PVC::Specio;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.001';
+our $VERSION   = '0.002';
 
 use parent qw(Benchmark::Featureset::ParamCheck::Base::PVC);
 use Params::ValidationCompiler 0.24 qw(validation_for);
@@ -28,4 +28,14 @@ sub get_named_check {
 	);
 }
 
+sub get_positional_check {
+	state $check = validation_for(
+		params => [
+			{ type => t('Int') },
+			{ type => t('ArrayRef', of => t('HashRef')) },
+			{ type => object_can_type('Printable', methods => [qw/ print close /]) },
+		],
+	);
+}
+
 1;
