@@ -5,7 +5,7 @@ use warnings;
 package Benchmark::Featureset::ParamCheck::Implementation::Perl;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.001';
+our $VERSION   = '0.002';
 
 use parent qw(Benchmark::Featureset::ParamCheck::Base);
 use Scalar::Util qw(blessed);
@@ -39,4 +39,28 @@ sub get_named_check {
 	};
 }
 
+sub get_positional_check {
+	state $check = sub {
+		die 'wrong number of parameters' unless @_==3;
+		
+		die 'bad integer' unless
+			defined($_[0])
+			&& !ref($_[0])
+			&& $_[0] =~ /\A-?[0-9]+\z/;
+		
+		die 'bad object' unless
+			blessed($_[2])
+			&& $_[2]->can('print')
+			&& $_[2]->can('close');
+		
+		die 'bad hashes' unless
+			ref($_[1]) eq 'ARRAY';
+		for my $arr (@{ $_[1] }) {
+			die 'bad hashes' unless ref($arr) eq 'HASH';
+		}
+		
+		@_;
+	};
+}
+
 1;
\ No newline at end of file
