@@ -5,12 +5,12 @@ use warnings;
 package Benchmark::Featureset::ParamCheck::Implementation::TypeParams;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.001';
+our $VERSION   = '0.002';
 
 use parent qw(Benchmark::Featureset::ParamCheck::Base);
 use Ref::Util 0.203 ();
 use Ref::Util::XS 0.116 ();
-use Type::Params 1.001_009 qw(compile_named);
+use Type::Params 1.001_009 qw(compile_named compile);
 use Types::Standard 1.001_009 -types;
 use Type::Tiny::XS 0.012 ();
 use namespace::autoclean;
@@ -26,4 +26,12 @@ sub get_named_check {
 	);
 }
 
+sub get_positional_check {
+	state $check = compile(
+		Int,
+		ArrayRef[HashRef],
+		HasMethods[qw/ print close /],
+	);
+}
+
 1;
\ No newline at end of file
